==> z2n-periodogram-1.8.3.tar.gz: z2n-periodogram-1.8.3/docs/index.md <==
# Welcome to the Z2n Periodogram Documentation

[![PyPI](https://img.shields.io/pypi/v/z2n-periodogram)](https://pypi.org/project/z2n-periodogram/)
[![GitHub issues](https://img.shields.io/github/issues/yohanalexander/z2n-periodogram)](https://github.com/yohanalexander/z2n-periodogram/issues)
[![GitHub](https://img.shields.io/github/license/yohanalexander/z2n-periodogram)](https://github.com/YohanAlexander/z2n-periodogram/blob/master/LICENSE)
[![Documentation Status](https://readthedocs.org/projects/z2n-periodogram/badge/?version=latest)](https://z2n-periodogram.readthedocs.io/en/latest/?badge=latest)

<br>
<p align="center">
  <a href="https://github.com/yohanalexander/z2n-periodogram">
    <img src="https://user-images.githubusercontent.com/39287022/84617670-23675480-aea6-11ea-90ac-93a32c01bb92.png" alt="Logo" width="50%" height="50%">
  </a>

  <h1 align="center">Z2n Periodogram</h1>

  <p align="center">
    A program for interative periodograms analysis!

## Table of Contents

* [About the Project](/about)
    * [Built with](/about/#built-with)
* [Getting Started](/install)
    * [Prerequesites](/install/#prerequesites)
    * [Installation](/install/#installation)
* [Usage](/input)
    * [Importing data to the program](/input)
    * [Using from the command line](/usage)
    * [Plotting the periodogram](/plotting)
* [API](/series)
    * [The Time Series Object](/series)
    * [The Plot Figure Object](/plot)
* [Contributing](/contribute)
    * [Roadmap](/contribute#roadmap)
* [License](/copyright)

==> z2n-periodogram-2.0.5.tar.gz: z2n-periodogram-2.0.5/docs/index.md <==
# Welcome to the Z2n Periodogram Documentation

[![PyPI](https://img.shields.io/pypi/v/z2n-periodogram)](https://pypi.org/project/z2n-periodogram/)
[![GitHub issues](https://img.shields.io/github/issues/yohanalexander/z2n-periodogram)](https://github.com/yohanalexander/z2n-periodogram/issues)
[![GitHub](https://img.shields.io/github/license/yohanalexander/z2n-periodogram)](https://github.com/YohanAlexander/z2n-periodogram/blob/master/LICENSE)
[![Documentation Status](https://readthedocs.org/projects/z2n-periodogram/badge/?version=latest)](https://z2n-periodogram.readthedocs.io/en/latest/?badge=latest)

<br>
<p align="center">
  <a href="https://github.com/yohanalexander/z2n-periodogram">
    <img src="https://user-images.githubusercontent.com/39287022/84617670-23675480-aea6-11ea-90ac-93a32c01bb92.png" alt="Logo" width="50%" height="50%">
  </a>

  <h1 align="center">Z2n Periodogram</h1>

  <p align="center">
    A package for interative periodograms analysis!

## Table of Contents

* [About the Project](/about)
    * [Built with](/about/#built-with)
* [The core computation](/performance)
* [Getting Started](/install)
    * [Prerequesites](/install/#prerequesites)
    * [Installation](/install/#installation)
    * [Known Issues](/install/#known-issues)
* [Usage](/input)
    * [Importing datasets](/input)
    * [Using from the terminal](/usage)
    * [Plotting the periodogram](/plotting)
    * [Determining uncertainty](/statistics)
* [API](/series)
    * [The Time Series Object](/series)
    * [The Plot Figure Object](/plot)
* [Contributing](/contribute)
    * [Roadmap](/contribute#roadmap)
* [License](/copyright)
